@@ -2,6 +2,7 @@
 # milieu - Environment variables manager
 #
 # Copyright (c) 2013  Yipit, Inc <coders@yipit.com>
+# Copyright (c) 2013-2014  Lincoln Clarete <lincoln@clarete.li>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,10 +23,9 @@ import os
 import urlparse
 import yaml
 
-version = __version__ = '0.1.0'
-
 
 class FolderStorage(dict):
+
     def __init__(self, path):
         # We won't do anything before making sure it's a folder
         if not os.path.isdir(path):
@@ -73,6 +73,14 @@ class Environment(object):
     def from_folder(cls, path):
         return cls(storage=FolderStorage(path))
 
+    def update(self, other_environment):
+        # We're not using the `dict.update()` method here because it
+        # doesn't actually call the `set` method, which is what
+        # actually writes to the disc in the `FolderStorage` for
+        # example.
+        for key, value in other_environment.items():
+            self.storage[key] = value
+
     def __delitem__(self, name):
         del self.storage[name]
 
